import logging

import click

from utoolbox.data import MicroManagerDataset, SPIMDataset
import utoolbox.data.dataset.error import DatasetError

__all__ = ["determine_format"]

logger = logging.getLogger(__name__)


@click.command("scan", short_help="scan and identify a dataset format")
@click.argument("root", type=click.Path(exists=True))
@click.pass_context
def determine_format(ctx, root):
    def _try_dataset_flavors(root):

        try:
            return SPIMDataset(root, refactor=False)
        except spim_error.SettingsNotFoundError:
            logger.info("not generated by SPIM")

        try:
            return MicroManagerDataset(root)
        except mm_error.NoMetadataInTileFolderError:
            logger.info("not generated by Micro-Manager")

        raise RuntimeError("unable to determine dataset flavor")

    for klass in (SPIMDataset, MicroManagerDataset):
        try:
            ds = klass(root)
            break
        except DatasetError:
            logger.debug(f"not \"{klass.__name__}\"")
    else:
        raise RuntimeError('unable to determine dataset flavor')
    
    print(ds.metadata)
